#!/bin/sh

# Copyright (C) 2017 Markus Eberl
#
# This Program is free software; you can redistribute it and/or modify
# it under the terms of the Attribution-NonCommercial 4.0 International (CC BY-NC 4.0) License
# as published by https://creativecommons.org/licenses/by-nc/4.0/legalcode 
#
# This Program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
#
#  file: mpcfadectl.sh
#  version: 1.0 2017-05-11
#  coder: Markus Eberl

MPC="/usr/bin/mpc";
TIMEOUT=60 ; #timeout after "fade in" in min

if [[ !(($1 = "in" && $# -eq 3) || ($1 = "out" && $# -eq 2))]] ; then
	echo "usage:";
	echo "mpc_fade in [end volume] [length in secs]";
	echo "mpc_fade out [length in secs]";
	exit 1 ;
fi

############## fade in ##############
if [ $1 = "in" ] ; then 
	$MPC volume 0 > /dev/null ;
	$MPC play > /dev/null ;
	
	VOLUME=0;

	while [ $VOLUME -lt $2 ] ; do
	
		CURRENT_VOLUME=`$MPC volume | sed -e 's/[^0-9]*\([0-9]*\).*/\1/'`
		
		#end fade if user changed volume
		Diff=$(($CURRENT_VOLUME - $VOLUME)) ;
		if [[ ${Diff#-} -gt 2 ]] ; then
			exit 0 ;
		fi;

		VOLUME=$(($VOLUME + 1)) ;		
		$MPC volume $VOLUME > /dev/null ;

		sleep `php -r "echo ($3/$2);"` ;
	done ;
	
	#Stops playing after 60 min without input
	echo "$MPC stop" | at now + $TIMEOUT min > /dev/null ;
	exit 0;
fi
	

############## fade out ##############
if [ $1 = "out" ] ; then
	echo "out"
	
	STOPTIME=$((`date +'%s'` + $2)) ;
	VOLUME=`$MPC volume | sed -e 's/[^0-9]*\([0-9]*\).*/\1/'` ;
	BACKUPVOLUME=$VOLUME ;
	TIME=`date +'%s'` ;			
	TIMESTEP=`php -r "echo (($STOPTIME - $TIME) /($VOLUME));"` ;		
	
	while [ $VOLUME -gt 0 ] ; do
		
		CURRENT_VOLUME=`$MPC volume | sed -e 's/[^0-9]*\([0-9]*\).*/\1/'` ;
		
		if [ $VOLUME -ne $CURRENT_VOLUME ] ; then		
			VOLUME=$CURRENT_VOLUME ;
			TIME=`date +'%s'` ;			
			TIMESTEP=`php -r "echo (($STOPTIME - $TIME) /($VOLUME));"` ;
		fi

		VOLUME=$(($VOLUME - 1)) ;		
		$MPC volume $VOLUME > /dev/null ;

		sleep $TIMESTEP ;				
	done ;
	
	$MPC stop > /dev/null ;
	$MPC volume $BACKUPVOLUME ;
	exit 0;
fi

echo "something went wrong" ;
exit 1 ;
# eof

